containers

package
v0.0.1-prerelease9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2024 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyAll

func ApplyAll[T any](t *T, opts ...Option[T])

ApplyAll takes a pointer to type T and it passes it onto each supplied Option function in the supplied order.

func FilterByKey

func FilterByKey[K comparable, V any](seq iter.Seq2[K, V], keyFn func(K) bool) iter.Seq2[K, V]

FilterByKey filters the provided sequence using the provided key function The result is a sequence containing only the entries where the key in the supplied sequence returns true when passed to keyFn

Types

type Option

type Option[T any] func(*T)

Option is any function which receives a pointer to any type T.

Jump to