Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyAll ¶
ApplyAll takes a pointer to type T and it passes it onto each supplied Option function in the supplied order.
func FilterByKey ¶
FilterByKey filters the provided sequence using the provided key function The result is a sequence containing only the entries where the key in the supplied sequence returns true when passed to keyFn
Types ¶
Click to show internal directories.
Click to hide internal directories.